@@ -1,21 +1,5 @@
 setMethod("proj4string", signature(obj = "Spatial"),
 	function(obj) {
-                if (!is.null(comment(slot(obj, "proj4string")))) {
-                  if (get("rgdal_show_exportToProj4_warnings",
-                    envir=.spOptions)) {
-                    if (!get("thin_PROJ6_warnings", envir=.spOptions)) {
-                      warning("CRS object has comment, which is lost in output; in tests, see\nhttps://cran.r-project.org/web/packages/sp/vignettes/CRS_warnings.html")
-                    } else {
-                      if (get("PROJ6_warnings_count",
-                        envir=.spOptions) == 0L) {
-                        warning("CRS object has comment, which is lost in output\n repeated warnings suppressed")
-                      }
-                      assign("PROJ6_warnings_count",
-                        get("PROJ6_warnings_count",
-                        envir=.spOptions) + 1L, envir=.spOptions)
-                   }
-                 }
-		}
                 res <- as.character(obj@proj4string@projargs)
                 res
         }
@@ -24,22 +8,6 @@ setMethod("proj4string", signature(obj = "Spatial"),
 setMethod("wkt", signature(obj = "Spatial"),
 	function(obj) {
                 comm <- comment(slot(obj, "proj4string"))
-                if (is.null(comm)) {
-                  if (get("rgdal_show_exportToProj4_warnings",
-                    envir=.spOptions)) {
-                    if (!get("thin_PROJ6_warnings", envir=.spOptions)) {
-                      warning("CRS object has no comment")
-                    } else {
-                      if (get("PROJ6_warnings_count",
-                        envir=.spOptions) == 0L) {
-                        warning("CRS object has no comment\n repeated warnings suppressed")
-                      }
-                      assign("PROJ6_warnings_count",
-                        get("PROJ6_warnings_count",
-                        envir=.spOptions) + 1L, envir=.spOptions)
-                   }
-                 }
-                }
 		comm
         }
 )
@@ -112,10 +80,9 @@ setMethod("is.projected", signature(obj = "Spatial"), is.projectedSpatial)
 is.projectedCRS <- function(obj) {
 	p4str <- slot(obj, "projargs")
 	wkt2 <- comment(obj)
-	if (is.null(wkt2) && is.na(p4str))
-		as.logical(NA)
-	else if (get("evolution_status", envir=.spOptions) == 2L) {
-		if (requireNamespace("sf", quietly = TRUE)) {
+	if (is.null(wkt2) && is.na(p4str)) # fast track for default objects
+	    return(NA)
+	if (requireNamespace("sf", quietly = TRUE)) {
 		    o <- try(sf::st_is_longlat(obj), silent=TRUE)
 # rbgm workaround for +proj=utm +zone=18 +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs +# +a=6378137.0 +es=0.006694380022900787 +lon_0=-75d00 +lat_0=0d00 +x_0=500000.0 +y_0=0.0 +k=0.9996 in bgmfiles Final_CAM_Boxes_8.bgm
                     if (inherits(o, "try-error"))
@@ -127,21 +94,9 @@ is.projectedCRS <- function(obj) {
                         warning("Package sf not available")
                     if (!is.null(wkt2)) # and old rgdal version
 		        substring(wkt2, 1, 3) != "GEO"
-	            else if (is.na(p4str) || !nzchar(p4str))
-		        as.logical(NA)
 	            else
 		        length(grep("longlat", p4str, fixed = TRUE)) == 0L
-                }
-	} else if (get("evolution_status", envir=.spOptions) == 0L && 
-			requireNamespace("rgdal", quietly = TRUE) &&
-			packageVersion("rgdal") >= "1.5.17" && rgdal::new_proj_and_gdal())
-		rgdal::OSRIsProjected(obj)
-	else if (!is.null(wkt2)) # and old rgdal version
-		substring(wkt2, 1, 3) != "GEO"
-	else if (is.na(p4str) || !nzchar(p4str))
-		as.logical(NA)
-	else
-		length(grep("longlat", p4str, fixed = TRUE)) == 0L
+        } 
 }
 
 setMethod("is.projected", signature(obj = "CRS"), is.projectedCRS)
